@@ -12,7 +12,7 @@ import uuid
 import zipfile
 import gzip
 from pathlib import Path
-
+import importlib.resources as pkg_resources
 import requests
 
 from ._service import _service_url
@@ -26,7 +26,7 @@ from ._utils import (
     _execute_iterator
 )
 from ._version import __version__
-
+from . import templates
 try:
     import zlib
     compression = zipfile.ZIP_DEFLATED
@@ -61,18 +61,17 @@ def _init():
 
     # Make idk config json
     with open("idk.json", "w+") as config_file:
-            config = {
-                "insight_name": insight_name,
-                "insight_file": insight_file,
-                "insight_class": class_name
-            }
-            json.dump(config, config_file, indent=4)
+        config = {
+            "insight_name": insight_name,
+            "insight_file": insight_file,
+            "insight_class": class_name
+        }
+        json.dump(config, config_file, indent=4)
 
-    resources_dir = Path(__file__).parent / "_resources"
     # Insight file
     with open(insight_file, "w+") as f:
-        with open(resources_dir / "_gen_template.py", "r") as tmpl:
-            f.write(tmpl.read().replace("_DeveloperInsight_", class_name))
+        template = pkg_resources.read_text(templates, "_gen_template.py")
+        f.write(template.replace("_DeveloperInsight_", class_name))
 
     # insight requirements
     with open("requirements.txt", "w+") as req:
@@ -85,24 +84,26 @@ def _init():
         )
 
     # Transcription Folder
-    transcip_dir = Path.cwd() / "transcription" 
+    transcip_dir = Path.cwd() / "transcription"
     Path.mkdir(transcip_dir)
     with open(transcip_dir / "transcribe.py", "w+") as f:
-        with open(resources_dir / "_trans_template.py", "r") as tmpl:
-            f.write(tmpl.read().replace("_DeveloperInsight_", class_name))
+        template = pkg_resources.read_text(templates, "_trans_template.py")
+        f.write(template.replace("_DeveloperInsight_", class_name))
 
     with open(transcip_dir / "requirements.transcription.txt", "w+") as f:
-        f.writelines(["# This is where you can write the required pip installs for your transcription function"])
+        f.writelines(
+            ["# This is where you can write the required pip installs for your transcription function"])
 
     # Tracking Folder
     tracking_dir = Path.cwd() / "tracking"
     Path.mkdir(tracking_dir)
     with open(tracking_dir / "tracking.py", "w+") as f:
-        with open(resources_dir / "_tracking_template.py", "r") as tmpl:
-            f.write(tmpl.read().replace("_DeveloperInsight_", class_name))
+        template = pkg_resources.read_text(templates, "_tracking_template.py")
+        f.write(template.replace("_DeveloperInsight_", class_name))
 
     with open(tracking_dir / "requirements.tracking.txt", "w+") as f:
-            f.writelines(["# This is where you can write the required pip installs for your tracking functions"])
+        f.writelines(
+            ["# This is where you can write the required pip installs for your tracking functions"])
 
     for output in _execute_iterator("python3 -m venv .venv"):
         logger.info(output)
@@ -169,7 +170,7 @@ def _destroy(test):
     # When we destroy we will need to delete the hashkey in order to make a new one next time it's deployed?
     # Probably yes for safety reasons (no risk of accidentally not deleting a lambda functions somewhere and)
     # THIS SHOULD DEFINITELY ONLY RUN IF WE'RE SURE ALL THE OTHER SERVICES HASVE DELETED THEIR PARTS.
-    shutil.rmtree(Path.cwd() /  ".idk.out")
+    shutil.rmtree(Path.cwd() / ".idk.out")
 
 
 def main():
